Helper class

Constructors

Helper({String srcAlpha = Helper.DEC, String dstAlpha = Helper.HEX})

Properties

dstAlpha String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
srcAlpha String
getter/setter pair

Methods

convert(dynamic number) → dynamic
isValid(dynamic number) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

BIN → const String
DEC → const String
HEX → const String
OCT → const String